/* Copyright (C) 2014 by Bundesamt für Sicherheit in der Informationstechnik
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU GPL (v>=2)
 * and comes with ABSOLUTELY NO WARRANTY!
 * See LICENSE.txt for details. */
#ifndef PROCESSWAITDIALOG_H
#define PROCESSWAITDIALOG_H

#include <QDialog>
#include <QStringList>

/** 
 * @file processwaitdialog.h
 * @brief Dialog to show that some processes need to be closed
 *
 * This dialog informs about processes that are still running and
 * need to be closed.
 */

class ProcessWaitDialog : public QDialog
{
    Q_OBJECT

public:
    /** @brief create the dialog
     *
     * The dialog is modal and will stay open until no more processes
     * with names from processnames exist.
     *
     * @param[in] parent the parent dialog
     * @param[in] processNames the names of the processes to wait for.
     */
    ProcessWaitDialog(QWidget *parent, const QStringList& processNames);

private slots:

    /** @brief update the process list */
    void updateProcesses();

private:

    QListWidget *mProcessList;
    const QStringList mProcessNames;
};

#endif // PROCESSWAITDIALOG_H
